# CyLa Mixture
Replaces some Cyrillic letters with similar Latin ones.

## Usage
1. Enter or paste text into the top form.
2. Click "Generate Mixture" button, or just press Ctrl + Enter.
3. The generated text will appear in the bottom form.

